@@ -13,8 +13,9 @@ class inputLanguagesController(GracieBaseAPI):
         parameters_names_map = {}
         api = '/input-languages/list'
         actions = ['post']
+        consumes = ['application/json']
         params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data)
+        return self._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieve(self, inputLanguageId):
         """
@@ -22,6 +23,9 @@ class inputLanguagesController(GracieBaseAPI):
         Args:
             inputLanguageId: (string): inputLanguageId
 
+        Consumes:
+            application/json
+
         Returns:
             application/json;charset=UTF-8
         """
@@ -30,5 +34,6 @@ class inputLanguagesController(GracieBaseAPI):
         parameters_names_map = {}
         api = '/input-languages/retrieve'
         actions = ['post']
+        consumes = ['application/json']
         params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data)
+        return self._process_api(self._controller_name, api, actions, params, data, consumes)
