@@ -12,6 +12,9 @@ class performanceController(GracieBaseAPI):
         Args:
             enabled: (boolean): enabled
 
+        Consumes:
+            application/json
+
         Returns:
             application/json;charset=UTF-8
         """
@@ -20,8 +23,9 @@ class performanceController(GracieBaseAPI):
         parameters_names_map = {}
         api = '/performance/enable'
         actions = ['post']
+        consumes = ['application/json']
         params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data)
+        return self._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieve(self):
         """"""
@@ -30,5 +34,6 @@ class performanceController(GracieBaseAPI):
         parameters_names_map = {}
         api = '/performance/retrieve'
         actions = ['post']
+        consumes = ['application/json']
         params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data)
+        return self._process_api(self._controller_name, api, actions, params, data, consumes)
