@@ -13,6 +13,9 @@ class taskTypesController(GracieBaseAPI):
             orderAsc: (boolean): orderAsc
             orderBy: (string): orderBy
 
+        Consumes:
+            application/json
+
         Returns:
             application/json;charset=UTF-8
         """
@@ -21,8 +24,9 @@ class taskTypesController(GracieBaseAPI):
         parameters_names_map = {}
         api = '/taskType/list'
         actions = ['post']
+        consumes = ['application/json']
         params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data)
+        return self._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieve(self, id):
         """
@@ -30,6 +34,9 @@ class taskTypesController(GracieBaseAPI):
         Args:
             id: (string): id
 
+        Consumes:
+            application/json
+
         Returns:
             application/json;charset=UTF-8
         """
@@ -38,5 +45,6 @@ class taskTypesController(GracieBaseAPI):
         parameters_names_map = {}
         api = '/taskType/retrieve'
         actions = ['post']
+        consumes = ['application/json']
         params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data)
+        return self._process_api(self._controller_name, api, actions, params, data, consumes)
