@@ -38,7 +38,7 @@ class testDocumentsController(GracieBaseAPI):
             testGroupId: (string): testGroupId
 
         Consumes:
-            application/json
+            multipart/form-data
 
         Returns:
             application/json;charset=UTF-8
@@ -48,7 +48,7 @@ class testDocumentsController(GracieBaseAPI):
         parameters_names_map = {}
         api = '/test-documents/addFile'
         actions = ['post']
-        consumes = ['application/json']
+        consumes = ['multipart/form-data']
         params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
         return self._process_api(self._controller_name, api, actions, params, data, consumes)
 
